Skip to contents

Computes the Palma ratio estimator for measuring inequality on simple and complex sampling data

Usage

palma_ratio(y, weights = NULL, type = 6, na.rm = TRUE)

Arguments

y

A numeric vector of data values

weights

A numeric vector of sampling weights (optional)

type

Quantile estimation type: integer 4-9 or HD for Harrell-Davis (default: 6). See csquantile documentation for a complete description.

na.rm

Logical, should missing values be removed? (default: TRUE)

Value

A scalar numeric value representing the estimated inequality by the Palma ratio.

Details

Consider a random sample \(s\) of size \(n\), and let \(w_j\), \(j \in s\), define the sampling weight and \(y_j\) be the observed characteristics (i.e. income) associated to the \(j\)-th individual, \(j = 1, \ldots, n\). According to Cobham and Sumner (2013) definition, the Palma index divides the share earned by the richest 10\ poorest 40\

$$\widehat{Palma} = \frac{\sum_{j \in s}w_j y_j \mathds{1}\left\{ y_j \geq \widehat{Q}(0.9)\right\} }{\sum_{j \in s} w_j y_j\mathds{1}\left\{ y_j \leq \widehat{Q}(0.4)\right\} }$$

where the estimated quantiles \(\widehat{Q}(p)\) are computed via the function csquantile(), which accounts for sampling weights and the specified quantile type. This allows \(\widehat{Palma}\) to be used both for simple random samples and for complex survey data with design weights.

See Palma (2006) and Palma (2011) for an introduction to the Palma ratio.

References

Palma JG (2006). “Globalizing Inequality: ‘Centrifugal’ and ‘Centripetal’ Forces at Work.” United Nations, Department of Economics and Social Affairs.

Palma JG (2011). “Homogeneous middles vs. heterogeneous tails, and the end of the ‘inverted-U’: It's all about the share of the rich.” Development and Change, 42, 87–153.

Cobham A, Sumner A (2013). “Is it all about the tails? The Palma measure of income inequality.” Center for Global Development working paper.

See also

Other inequality indicators based on quantiles: inequantiles(), plot_inequality_curve(), qri(), qsr(), ratio_quantiles()

Examples


data(synthouse)

eq <- synthouse$eq_income ### Income data

# Compute unweighted Palma index with default type 6 quantile estimator
palma_ratio(y = eq)
#> [1] 1.568589

# Consider the sampling weights and change quantile estimation type
w <- synthouse$weight
palma_ratio(y = eq, weights = w, type = 5)
#> [1] 1.578482

# Compare the Palma index across macro-regions (NUTS1)
tapply(1:nrow(synthouse), synthouse$NUTS1, function(area) {
  palma_ratio(y = synthouse$eq_income[area],
      weights = synthouse$weight[area],
      type = 6)
})
#>        C        N       NE       NO        S 
#> 1.629047 1.588659 1.624684 1.739012 1.455656